@@ -28,7 +28,7 @@ int main(int argc, char *argv[])
 {
 	QApplication app(argc, argv);
 	SegatexAlertAudit mainWin;
-	app.setMainWidget(&mainWin);
+	//app.setMainWidget(&mainWin);
 	mainWin.show();
 	return app.exec();
 }
