@@ -21,6 +21,9 @@
 #include <qapplication.h>
 #include <qsplashscreen.h>
 #include <qtextcodec.h>
+//Added by qt3to4:
+#include <QTranslator>
+#include <QPixmap>
 //testing for daemon
 #include <stdlib.h>
 
@@ -33,7 +36,10 @@ int main(int argc, char *argv[])
 	appTranslator.load(QString("segatex_") + QTextCodec::locale(),
 				"/root/segatex");
 	app.installTranslator(&appTranslator);
-	QSplashScreen *splash = new QSplashScreen(QPixmap::fromMimeSource("/root/segatex/splash.png"));
+	//QSplashScreen *splash = new QSplashScreen(QPixmap::fromMimeSource("/root/segatex/splash.png"));
+	QPixmap splashIcon = QPixmap(":/document.png");
+	QSplashScreen *splash = new QSplashScreen(splashIcon);
+
 	splash->show();
 	splash->message(QObject::tr("Setting up the main window..."),
 			Qt::AlignRight | Qt::AlignTop, Qt::white);
