@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2008 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,11 +32,16 @@
 //newly added
 #include <qsplitter.h>
 #include <qpushbutton.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <Q3PopupMenu>
+#include <QCloseEvent>
 
 #include "editor.h"
 
 #include "breakte.h"
+#include "breakif.h"
 #include "segatex_state.h"
 #include "segatex_apply.h"
 #include "segatex_setenforce.h"
@@ -62,18 +67,21 @@
 #include "downloader.h"
 
 MainWindow::MainWindow(QWidget *parent, const char *name)
-	: QMainWindow(parent, name)
+	: Q3MainWindow(parent, name)
 {
 	//newly added
-	horizontalSplitter = new QSplitter(Horizontal, this);
+	//horizontalSplitter = new QSplitter(Horizontal, this);
+	horizontalSplitter = new QSplitter(Qt::Horizontal, this);
 	setCentralWidget(horizontalSplitter);
 	//declare workspace as a child of horizontalSplitter
 	workspace = new QWorkspace(horizontalSplitter);
 
 	breakte = new BreakTe();
+	breakif = new BreakIf();
 	segatex_state = new SegatexState();
 	//needs here to be declared when opening a new window unless segmentation fualt happens...
 	breakte_o = 0;
+	breakif_o = 0;
 	segatex_apply = 0;
 	selinux_yum = 0;
 	selinux_yum_process = 0;
@@ -109,232 +117,312 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex-6.80"));
-	setIcon(QPixmap::fromMimeSource("icon.png"));
+	//setCaption(tr("segatex-7.00"));
+	setWindowTitle(tr("segatex-7.10"));
+	////setIcon(QPixmap::fromMimeSource("icon.png"));
+	QPixmap myIcon1 = QPixmap(":/images/icon.png");
+	this->setIcon(myIcon1);
+
+	//m_NewAction = new QAction(QIcon(":/images/icon.png"), tr("segatex-7.00"), this);
+	//new QAction(QIcon(":/images/icon.png"), tr("test-segatex-7.00"), this);
 }
 
 void MainWindow::createActions()
 {
-	newAct = new QAction(tr("&New"), tr("Ctrl+N"), this);
-	newAct->setIconSet(QPixmap::fromMimeSource("new.png"));
+	//newAct = new QAction(tr("&New"), tr("Ctrl+N"), this);
+	newAct = new QAction(tr("&New"), this);
+	newAct->setShortcut(tr("Ctrl+N"));
+	//newAct->setIconSet(QPixmap::fromMimeSource("new.png"));
+	QPixmap myIcon2 = QPixmap(":/images/new.png");
+	newAct->setIcon(myIcon2);
 	newAct->setStatusTip(tr("Create a new file"));
 	connect(newAct, SIGNAL(activated()), this, SLOT(newFile()));
 	connect(newAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	openAct = new QAction(tr("&Open..."), tr("Ctrl+O"), this);
-	openAct->setIconSet(QPixmap::fromMimeSource("open.png"));
+	//openAct = new QAction(tr("&Open..."), tr("Ctrl+O"), this);
+	openAct = new QAction(tr("&Open..."), this);
+	openAct->setShortcut(tr("Ctrl+O"));
+	//openAct->setIconSet(QPixmap::fromMimeSource("open.png"));
+	QPixmap myIcon3 = QPixmap(":/images/open.png");
+	openAct->setIcon(myIcon3);
 	openAct->setStatusTip(tr("Open an existing file"));
 	connect(openAct, SIGNAL(activated()), this, SLOT(open()));
 	connect(openAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	saveAct = new QAction(tr("&Save"), tr("Ctrl+S"), this);
-	saveAct->setIconSet(QPixmap::fromMimeSource("save.png"));
+	//saveAct = new QAction(tr("&Save"), tr("Ctrl+S"), this);
+	saveAct = new QAction(tr("&Save"), this);
+	saveAct->setShortcut(tr("Ctrl+S"));
+	//saveAct->setIconSet(QPixmap::fromMimeSource("save.png"));
+	QPixmap myIcon4 = QPixmap(":/images/save.png");
+	saveAct->setIcon(myIcon4);
 	saveAct->setStatusTip(tr("Save the file to disk"));
 	connect(saveAct, SIGNAL(activated()), this, SLOT(save()));
 	connect(saveAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	saveAsAct = new QAction(tr("Save &As..."), 0, this);
+	//saveAsAct = new QAction(tr("Save &As..."), 0, this);
+	saveAsAct = new QAction(tr("Save &As..."), this);
 	saveAsAct->setStatusTip(tr("Save the file under a new name"));
 	connect(saveAsAct, SIGNAL(activated()), this, SLOT(saveAs()));
 	connect(saveAsAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	exitAct = new QAction(tr("E&xit"), tr("Ctrl+Q"), this);
+	//exitAct = new QAction(tr("E&xit"), tr("Ctrl+Q"), this);
+	exitAct = new QAction(tr("E&xit"), this);
+	exitAct->setShortcut(tr("Ctrl+Q"));
 	exitAct->setStatusTip(tr("Exit the application"));
 	connect(exitAct, SIGNAL(activated()), this, SLOT(close()));
 	connect(exitAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	cutAct = new QAction(tr("Cu&t"), tr("Ctrl+X"), this);
-	cutAct->setIconSet(QPixmap::fromMimeSource("cut.png"));
+	//cutAct = new QAction(tr("Cu&t"), tr("Ctrl+X"), this);
+	cutAct = new QAction(tr("Cu&t"), this);
+	cutAct->setShortcut(tr("Ctrl+X"));
+	//cutAct->setIconSet(QPixmap::fromMimeSource("cut.png"));
+	QPixmap myIcon5 = QPixmap(":/images/cut.png");
+	cutAct->setIcon(myIcon5);
 	cutAct->setStatusTip(tr("Cut the current selection to the "
 			    "clipboard"));
 	connect(cutAct, SIGNAL(activated()), this, SLOT(cut()));
 	connect(cutAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	copyAct = new QAction(tr("&Copy"), tr("Ctrl+C"), this);
-	copyAct->setIconSet(QPixmap::fromMimeSource("copy.png"));
+	//copyAct = new QAction(tr("&Copy"), tr("Ctrl+C"), this);
+	copyAct = new QAction(tr("&Copy"), this);
+	copyAct->setShortcut(tr("Ctrl+C"));
+	//copyAct->setIconSet(QPixmap::fromMimeSource("copy.png"));
+	QPixmap myIcon6 = QPixmap(":/images/copy.png");
+	copyAct->setIcon(myIcon6);
 	copyAct->setStatusTip(tr("Copy the current selection to the "
 			     "clipboard"));
 	connect(copyAct, SIGNAL(activated()), this, SLOT(copy()));
 	connect(copyAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	pasteAct = new QAction(tr("&Paste"), tr("Ctrl+V"), this);
-	pasteAct->setIconSet(QPixmap::fromMimeSource("paste.png"));
+	//pasteAct = new QAction(tr("&Paste"), tr("Ctrl+V"), this);
+	pasteAct = new QAction(tr("&Paste"), this);
+	pasteAct->setShortcut(tr("Ctrl+V"));
+	//pasteAct->setIconSet(QPixmap::fromMimeSource("paste.png"));
+	QPixmap myIcon7 = QPixmap(":/images/paste.png");
+	pasteAct->setIcon(myIcon7);
 	pasteAct->setStatusTip(tr("Paste the clipboard's contents at "
 			      "the cursor position"));
 	connect(pasteAct, SIGNAL(activated()), this, SLOT(paste()));
 	connect(pasteAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	deleteAct = new QAction(tr("&Delete"), tr("Del"), this);
-	deleteAct->setIconSet(QPixmap::fromMimeSource("delete.png"));
+	//deleteAct = new QAction(tr("&Delete"), tr("Del"), this);
+	deleteAct = new QAction(tr("&Delete"), this);
+	deleteAct->setShortcut(tr("Del"));
+	//deleteAct->setIconSet(QPixmap::fromMimeSource("delete.png"));
+	QPixmap myIcon8 = QPixmap(":/images/delete.png");
+	deleteAct->setIcon(myIcon8);
 	deleteAct->setStatusTip(tr("Delete the current selection"));
 	connect(deleteAct, SIGNAL(activated()), this, SLOT(del()));
 	connect(deleteAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	closeAct = new QAction(tr("Cl&ose"), tr("Ctrl+F4"), this);
+	//closeAct = new QAction(tr("Cl&ose"), tr("Ctrl+F4"), this);
+	closeAct = new QAction(tr("Cl&ose"), this);
+	closeAct->setShortcut(tr("Ctrl+F4"));
 	closeAct->setStatusTip(tr("Close the active window"));
 	connect(closeAct, SIGNAL(activated()),
 		workspace, SLOT(closeActiveWindow()));
 	connect(closeAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	closeAllAct = new QAction(tr("Close &All"), 0, this);
+	//closeAllAct = new QAction(tr("Close &All"), 0, this);
+	closeAllAct = new QAction(tr("Close &All"), this);
 	closeAllAct->setStatusTip(tr("Close all the windows"));
 	connect(closeAllAct, SIGNAL(activated()),
 		workspace, SLOT(closeAllWindows()));
 	connect(closeAllAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	tileAct = new QAction(tr("&Tile"), 0, this);
+	//tileAct = new QAction(tr("&Tile"), 0, this);
+	tileAct = new QAction(tr("&Tile"), this);
 	tileAct->setStatusTip(tr("Tile the windows"));
 	connect(tileAct, SIGNAL(activated()), workspace, SLOT(tile()));
 	connect(tileAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	cascadeAct = new QAction(tr("&Cascade"), 0, this);
+	//cascadeAct = new QAction(tr("&Cascade"), 0, this);
+	cascadeAct = new QAction(tr("&Cascade"), this);
 	cascadeAct->setStatusTip(tr("Cascade the windows"));
 	connect(cascadeAct, SIGNAL(activated()),
 		workspace, SLOT(cascade()));
 	connect(cascadeAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	nextAct = new QAction(tr("Ne&xt"), tr("Ctrl+F6"), this);
+	//nextAct = new QAction(tr("Ne&xt"), tr("Ctrl+F6"), this);
+	nextAct = new QAction(tr("Ne&xt"), this);
+	nextAct->setShortcut(tr("Ctrl+F6"));
 	nextAct->setStatusTip(tr("Move the focus to the next window"));
 	connect(nextAct, SIGNAL(activated()),
 		workspace, SLOT(activateNextWindow()));
 	connect(nextAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
+	//previousAct = new QAction(tr("Pre&vious"),
+			      //tr("Ctrl+Shift+F6"), this);
 	previousAct = new QAction(tr("Pre&vious"),
-			      tr("Ctrl+Shift+F6"), this);
+			       this);
+	previousAct->setShortcut(tr("Ctrl+F7"));
 	previousAct->setStatusTip(tr("Move the focus to the previous "
 				 "window"));
 	connect(previousAct, SIGNAL(activated()),
 		workspace, SLOT(activatePreviousWindow()));
 	connect(previousAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	aboutAct = new QAction(tr("&About"), 0, this);
+	//aboutAct = new QAction(tr("&About"), 0, this);
+	aboutAct = new QAction(tr("&About"), this);
 	aboutAct->setStatusTip(tr("Show the application's About box"));
 	connect(aboutAct, SIGNAL(activated()), this, SLOT(about()));
 	connect(aboutAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
 
-	aboutQtAct = new QAction(tr("About &Qt"), 0, this);
+	//aboutQtAct = new QAction(tr("About &Qt"), 0, this);
+	aboutQtAct = new QAction(tr("About &Qt"), this);
 	aboutQtAct->setStatusTip(tr("Show the Qt library's About box"));
 	connect(aboutQtAct, SIGNAL(activated()), qApp, SLOT(aboutQt()));
 	connect(aboutQtAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
 	//newly added-1:create action
-	breakteAct = new QAction(tr("Breake &te"), 0, this);
+	//breakteAct = new QAction(tr("Breake &te"), 0, this);
+	breakteAct = new QAction(tr("Breake &te"), this);
 	breakteAct->setStatusTip(tr("Break .te files"));
 	//connect(breakteAct, SIGNAL(activated()), breakte, SLOT(break_te()));
 	connect(breakteAct, SIGNAL(activated()), this, SLOT(break_te()));
 	connect(breakteAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	howtouseAct = new QAction(tr("&How to use"), 0, this);
+	//breakifAct = new QAction(tr("Breake &if"), 0, this);
+	breakifAct = new QAction(tr("Breake &if"), this);
+	breakifAct->setStatusTip(tr("Break .if files"));
+	//connect(breakifAct, SIGNAL(activated()), breakif, SLOT(break_if()));
+	connect(breakifAct, SIGNAL(activated()), this, SLOT(break_if()));
+	connect(breakifAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	//howtouseAct = new QAction(tr("&How to use"), 0, this);
+	howtouseAct = new QAction(tr("&How to use"), this);
 	howtouseAct->setStatusTip(tr("Show the application's How to use box"));
 	connect(howtouseAct, SIGNAL(activated()), this, SLOT(howtouse()));
 	connect(howtouseAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	enforcingAct = new QAction(tr("Change SELinux &state"), 0, this);
+	//enforcingAct = new QAction(tr("Change SELinux &state"), 0, this);
+	enforcingAct = new QAction(tr("Change SELinux &state"), this);
 	enforcingAct->setStatusTip(tr("Change Enforcing / Permissive"));
 	connect(enforcingAct, SIGNAL(activated()), this, SLOT(enforcing()));
 	connect(enforcingAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	check_selinuxAct = new QAction(tr("&Check SELinux state"), 0, this);
+	//check_selinuxAct = new QAction(tr("&Check SELinux state"), 0, this);
+	check_selinuxAct = new QAction(tr("&Check SELinux state"), this);
 	check_selinuxAct->setStatusTip(tr("Check SELinux State at present"));
 	connect(check_selinuxAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	default_policyAct = new QAction(tr("&Default SELinux policy type"), 0, this);
+	//default_policyAct = new QAction(tr("&Default SELinux policy type"), 0, this);
+	default_policyAct = new QAction(tr("&Default SELinux policy type"), this);
 	default_policyAct->setStatusTip(tr("Check SELinux default policy type"));
 	connect(default_policyAct, SIGNAL(activated()), segatex_state, SLOT(default_policy_type()));
 	connect(default_policyAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	selinuxYumAct = new QAction(tr("&Yum install/update"), 0, this);
+	//selinuxYumAct = new QAction(tr("&Yum install/update"), 0, this);
+	selinuxYumAct = new QAction(tr("&Yum install/update"), this);
 	selinuxYumAct->setStatusTip(tr("Yum install/update SELinux related RPMs."));
 	connect(selinuxYumAct, SIGNAL(activated()), this, SLOT(yum_selinux()));
 	connect(selinuxYumAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	selinuxYumProcessAct = new QAction(tr("&Yum install/update"), 0, this);
+	//selinuxYumProcessAct = new QAction(tr("&Yum install/update"), 0, this);
+	selinuxYumProcessAct = new QAction(tr("&Yum install/update"), this);
 	selinuxYumProcessAct->setStatusTip(tr("Yum install/update SELinux related RPMs."));
 	connect(selinuxYumProcessAct, SIGNAL(activated()), this, SLOT(yum_selinux_process()));
 	connect(selinuxYumProcessAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	audit2allowAct = new QAction(tr("&Audit2allow"), 0, this);
+	//audit2allowAct = new QAction(tr("&Audit2allow"), 0, this);
+	audit2allowAct = new QAction(tr("&Audit2allow"), this);
 	audit2allowAct->setStatusTip(tr("audit2allow"));
 	connect(audit2allowAct, SIGNAL(activated()), this, SLOT(audit2allow()));
 	connect(audit2allowAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	segatex_coreAct = new QAction(tr("Analize audit.&log"), 0, this);
+	//segatex_coreAct = new QAction(tr("Analize audit.&log"), 0, this);
+	segatex_coreAct = new QAction(tr("Analize audit.&log"), this);
 	segatex_coreAct->setStatusTip(tr("Analize audit.log in many ways."));
 	connect(segatex_coreAct, SIGNAL(activated()), this, SLOT(segatex_core()));
 	connect(segatex_coreAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	semodule_core_processAct = new QAction(tr("&Modules"), 0, this);
+	//semodule_core_processAct = new QAction(tr("&Modules"), 0, this);
+	semodule_core_processAct = new QAction(tr("&Modules"), this);
 	semodule_core_processAct->setStatusTip(tr("Modules."));
 	connect(semodule_core_processAct, SIGNAL(activated()), this, SLOT(semodule_core_process()));
 	connect(semodule_core_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	semanage_core_processAct = new QAction(tr("&list objects"), 0, this);
+	//semanage_core_processAct = new QAction(tr("&list objects"), 0, this);
+	semanage_core_processAct = new QAction(tr("&list objects"), this);
 	semanage_core_processAct->setStatusTip(tr("Semanage login -l user -l boolean -l port -l interface -l fcontext -l translation -l."));
 	connect(semanage_core_processAct, SIGNAL(activated()), this, SLOT(semanage_core_process()));
 	connect(semanage_core_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	semanage_core_login_processAct = new QAction(tr("semanage l&ogin"), 0, this);
+	//semanage_core_login_processAct = new QAction(tr("semanage l&ogin"), 0, this);
+	semanage_core_login_processAct = new QAction(tr("semanage l&ogin"), this);
 	semanage_core_login_processAct->setStatusTip(tr("Semanage login -a -m -d."));
 	connect(semanage_core_login_processAct, SIGNAL(activated()), this, SLOT(semanage_core_login_process()));
 	connect(semanage_core_login_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	semanage_core_fcontext_processAct = new QAction(tr("semanage &fcontext"), 0, this);
+	//semanage_core_fcontext_processAct = new QAction(tr("semanage &fcontext"), 0, this);
+	semanage_core_fcontext_processAct = new QAction(tr("semanage &fcontext"), this);
 	semanage_core_fcontext_processAct->setStatusTip(tr("Semanage fcontext -a -m -d."));
 	connect(semanage_core_fcontext_processAct, SIGNAL(activated()), this, SLOT(semanage_core_fcontext_process()));
 	connect(semanage_core_fcontext_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	semanage_core_port_processAct = new QAction(tr("semanage &port"), 0, this);
+	//semanage_core_port_processAct = new QAction(tr("semanage &port"), 0, this);
+	semanage_core_port_processAct = new QAction(tr("semanage &port"), this);
 	semanage_core_port_processAct->setStatusTip(tr("Semanage port -a -m -d."));
 	connect(semanage_core_port_processAct, SIGNAL(activated()), this, SLOT(semanage_core_port_process()));
 	connect(semanage_core_port_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	semanage_core_translation_processAct = new QAction(tr("semanage &translation"), 0, this);
+	//semanage_core_translation_processAct = new QAction(tr("semanage &translation"), 0, this);
+	semanage_core_translation_processAct = new QAction(tr("semanage &translation"), this);
 	semanage_core_translation_processAct->setStatusTip(tr("Semanage translation -a -m -d."));
 	connect(semanage_core_translation_processAct, SIGNAL(activated()), this, SLOT(semanage_core_translation_process()));
 	connect(semanage_core_translation_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	semanage_core_boolean_processAct = new QAction(tr("setse&bool "), 0, this);
+	//semanage_core_boolean_processAct = new QAction(tr("setse&bool "), 0, this);
+	semanage_core_boolean_processAct = new QAction(tr("setse&bool "), this);
 	semanage_core_boolean_processAct->setStatusTip(tr("setsebool [-P] boolean value."));
 	connect(semanage_core_boolean_processAct, SIGNAL(activated()), this, SLOT(semanage_core_boolean_process()));
 	connect(semanage_core_boolean_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	autorelabel_processAct = new QAction(tr("auto&relabel "), 0, this);
+	//autorelabel_processAct = new QAction(tr("auto&relabel "), 0, this);
+	autorelabel_processAct = new QAction(tr("auto&relabel "), this);
 	autorelabel_processAct->setStatusTip(tr("autorelabel the system."));
 	connect(autorelabel_processAct, SIGNAL(activated()), this, SLOT(autorelabel_process()));
 	connect(autorelabel_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	policygeneration_processAct = new QAction(tr("Policy_&module "), 0, this);
+	//policygeneration_processAct = new QAction(tr("Policy_&module "), 0, this);
+	policygeneration_processAct = new QAction(tr("Policy_&module "), this);
 	policygeneration_processAct->setStatusTip(tr("Generate policy_module."));
 	connect(policygeneration_processAct, SIGNAL(activated()), this, SLOT(policygeneration_process()));
 	connect(policygeneration_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	aureportAct = new QAction(tr("&Aureport"), 0, this);
+	//aureportAct = new QAction(tr("&Aureport"), 0, this);
+	aureportAct = new QAction(tr("&Aureport"), this);
 	aureportAct->setStatusTip(tr("Aureport"));
 	connect(aureportAct, SIGNAL(activated()), this, SLOT(aureport()));
 	connect(aureportAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	ausearchAct = new QAction(tr("&Ausearch"), 0, this);
+	//ausearchAct = new QAction(tr("&Ausearch"), 0, this);
+	ausearchAct = new QAction(tr("&Ausearch"), this);
 	aureportAct->setStatusTip(tr("Ausearch"));
 	connect(ausearchAct, SIGNAL(activated()), this, SLOT(ausearch()));
 	connect(ausearchAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	useraddAct = new QAction(tr("&Useradd/delete"), 0, this);
+	//useraddAct = new QAction(tr("&Useradd/delete"), 0, this);
+	useraddAct = new QAction(tr("&Useradd/delete"), this);
 	useraddAct->setStatusTip(tr("useradd/delete"));
 	connect(useraddAct, SIGNAL(activated()), this, SLOT(useradd()));
 	connect(useraddAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	seeprocessAct = new QAction(tr("&see process"), 0, this);
+	//seeprocessAct = new QAction(tr("&see process"), 0, this);
+	seeprocessAct = new QAction(tr("&see process"), this);
 	seeprocessAct->setStatusTip(tr("see process"));
 	connect(seeprocessAct, SIGNAL(activated()), this, SLOT(seeprocess()));
 	connect(seeprocessAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	restoreconAct = new QAction(tr("&restorecon"), 0, this);
+	//restoreconAct = new QAction(tr("&restorecon"), 0, this);
+	restoreconAct = new QAction(tr("&restorecon"), this);
 	restoreconAct->setStatusTip(tr("restorecon"));
 	connect(restoreconAct, SIGNAL(activated()), this, SLOT(restorecon()));
 	connect(restoreconAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
-	downloaderAct = new QAction(tr("&download Fedora"), 0, this);
+	//downloaderAct = new QAction(tr("&download Fedora"), 0, this);
+	downloaderAct = new QAction(tr("&download Fedora"), this);
 	downloaderAct->setStatusTip(tr("download Fedora"));
 	connect(downloaderAct, SIGNAL(activated()), this, SLOT(downloader()));
 	connect(downloaderAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
@@ -342,7 +430,7 @@ void MainWindow::createActions()
 
 void MainWindow::createMenus()
 {
-	fileMenu = new QPopupMenu(this);
+	fileMenu = new Q3PopupMenu(this);
 	newAct->addTo(fileMenu);
 	openAct->addTo(fileMenu);
 	saveAct->addTo(fileMenu);
@@ -350,43 +438,45 @@ void MainWindow::createMenus()
 	fileMenu->insertSeparator();
 	exitAct->addTo(fileMenu);
 
-	editMenu = new QPopupMenu(this);
+	editMenu = new Q3PopupMenu(this);
 	cutAct->addTo(editMenu);
 	copyAct->addTo(editMenu);
 	pasteAct->addTo(editMenu);
 	deleteAct->addTo(editMenu);
 
-	windowsMenu = new QPopupMenu(this);
+	windowsMenu = new Q3PopupMenu(this);
 	createWindowsMenu();
 
-	helpMenu = new QPopupMenu(this);
+	helpMenu = new Q3PopupMenu(this);
 	//newly added
 	howtouseAct->addTo(helpMenu);
 	aboutAct->addTo(helpMenu);
 	aboutQtAct->addTo(helpMenu);
 
 	//newly added-2:add actino to menu
-	breakteMenu = new QPopupMenu(this);
+	breakteMenu = new Q3PopupMenu(this);
 	breakteAct->addTo(breakteMenu);
+	breakifMenu = new Q3PopupMenu(this);
+	breakifAct->addTo(breakifMenu);
 
 	//newly added
-	auditMenu = new QPopupMenu(this);
+	auditMenu = new Q3PopupMenu(this);
 	segatex_coreAct->addTo(auditMenu);
 	audit2allowAct->addTo(auditMenu);
 	aureportAct->addTo(auditMenu);
 	ausearchAct->addTo(auditMenu);
 
-	policyMenu = new QPopupMenu(this);
+	policyMenu = new Q3PopupMenu(this);
 	selinuxYumProcessAct->addTo(policyMenu);
 	enforcingAct->addTo(policyMenu);
 	check_selinuxAct->addTo(policyMenu);
 	default_policyAct->addTo(policyMenu);
 
-	manageMenu = new QPopupMenu(this);
+	manageMenu = new Q3PopupMenu(this);
 	semodule_core_processAct->addTo(manageMenu);
 	policygeneration_processAct->addTo(manageMenu);
 
-	semanageMenu = new QPopupMenu(this);
+	semanageMenu = new Q3PopupMenu(this);
 	semanage_core_processAct->addTo(semanageMenu);
 	semanage_core_login_processAct->addTo(semanageMenu);
 	semanage_core_fcontext_processAct->addTo(semanageMenu);
@@ -394,14 +484,14 @@ void MainWindow::createMenus()
 	semanage_core_translation_processAct->addTo(semanageMenu);
 	semanage_core_boolean_processAct->addTo(semanageMenu);
 
-	relabelMenu = new QPopupMenu(this);
+	relabelMenu = new Q3PopupMenu(this);
 	restoreconAct->addTo(relabelMenu);
 	autorelabel_processAct->addTo(relabelMenu);
 
-	downloaderMenu = new QPopupMenu(this);
+	downloaderMenu = new Q3PopupMenu(this);
 	downloaderAct->addTo(downloaderMenu);
 
-	miscellaneousMenu = new QPopupMenu(this);
+	miscellaneousMenu = new Q3PopupMenu(this);
 	useraddAct->addTo(miscellaneousMenu);
 	seeprocessAct->addTo(miscellaneousMenu);
 
@@ -418,6 +508,7 @@ void MainWindow::createMenus()
 
 	menuBar()->insertSeparator();
 	menuBar()->insertItem(tr("Break .&te"), breakteMenu);
+	menuBar()->insertItem(tr("Break .&if"), breakifMenu);
 
 	menuBar()->insertSeparator();
 	menuBar()->insertItem(tr("Re&label"), relabelMenu);
@@ -434,12 +525,12 @@ void MainWindow::createMenus()
 
 void MainWindow::createToolBars()
 {
-	fileToolBar = new QToolBar(tr("File"), this);
+	fileToolBar = new Q3ToolBar(tr("File"), this);
 	newAct->addTo(fileToolBar);
 	openAct->addTo(fileToolBar);
 	saveAct->addTo(fileToolBar);
 
-	editToolBar = new QToolBar(tr("Edit"), this);
+	editToolBar = new Q3ToolBar(tr("Edit"), this);
 	cutAct->addTo(editToolBar);
 	copyAct->addTo(editToolBar);
 	pasteAct->addTo(editToolBar);
@@ -460,9 +551,11 @@ void MainWindow::createStatusBar()
 	else
 	selinux_policy = "SELinux is " + enabled_or_not_str + " and policy " + selinux_policy + " is moving in " + getenforce_str + " mode.";
 	segatexStateLabel = new QLabel(tr(selinux_policy), this);
-	segatexStateLabel->setAlignment(AlignHCenter);
+	//segatexStateLabel->setAlignment(AlignHCenter);
+	segatexStateLabel->setAlignment(Qt::AlignHCenter);
 
-	modLabel->setAlignment(AlignHCenter);
+	//modLabel->setAlignment(AlignHCenter);
+	modLabel->setAlignment(Qt::AlignHCenter);
 	modLabel->setMinimumSize(modLabel->sizeHint());
 	modLabel->clear();
 
@@ -595,8 +688,8 @@ void MainWindow::notice()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-6.80</h2>"
-		"<p>Copyright &copy; 2007-2008"
+		tr("<h2>segatex-7.10</h2>"
+		"<p>Copyright &copy; 2007-2009"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex is a SELinux tool"
 		"<p><b>written with Qt</b>."));
@@ -625,7 +718,7 @@ void MainWindow::howtouse()
 		" You can add/delete Linux user."
 		" You can ftp download."
 		"<p><font color=\"blue\">[segatex_editor]</font>"
-		"<p>Push break .te"
+		"<p>Push break .te or .if"
 		""));
 }
 
@@ -742,7 +835,15 @@ void MainWindow::break_te()
 	breakte_o->raise();
 	breakte_o->setActiveWindow();
 }
-
+void MainWindow::break_if()
+{
+	if(!breakif_o) {
+		breakif_o = new BreakIf(this);
+	}
+	breakif_o->show();
+	breakif_o->raise();
+	breakif_o->setActiveWindow();
+}
 void MainWindow::yum_selinux()
 {
 	if(!selinux_yum) {
