@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2008 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  * shintaro.fujiwara@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,29 +22,22 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-#include <qmainwindow.h>
-#include <qwidgetlist.h>
+#include <q3mainwindow.h>
+#include <qwidget.h>
+//Added by qt3to4:
+#include <QCloseEvent>
+#include <QLabel>
+#include <Q3PopupMenu>
 
 class QAction;
 class QLabel;
 class QWorkspace;
 class QSplitter;
-class QTextEdit;
+class Q3TextEdit;
 class QPushButton;
 class Editor;
 class BreakTe;
-/*
-class ParseLines;
-class ParseLinesAdmin;
-class ParseLinesApps;
-class ParseLinesKernel;
-class ParseLinesServices;
-class ParseLinesSystem;
-class ParseLinesMisc;
-class ParseLinesSelpaw;
-class Selpaw;
-class SelpawAdjust;
-*/
+class BreakIf;
 class SegatexState;
 class SegatexApply;
 class SegatexSetenforce;
@@ -68,7 +61,7 @@ class Seeprocess;
 class Restorecon;
 class Downloader;
 
-class MainWindow : public QMainWindow
+class MainWindow : public Q3MainWindow
 {
     Q_OBJECT
 public:
@@ -88,6 +81,7 @@ private slots:
     //newly added
     //void open_break_te_raw();
     void break_te();
+    void break_if();
     void howtouse();
     void enforcing();
     void yum_selinux();
@@ -144,12 +138,13 @@ private:
     //newly added
     QSplitter *topSplitter;
     QSplitter *horizontalSplitter;
-    QTextEdit *textEcho;
+    Q3TextEdit *textEcho;
     QString selinux_policy;
     QString enabled_or_not_str;
     QString getenforce_str;
 
     BreakTe *breakte;
+    BreakIf *breakif;
     SegatexState *segatex_state;
     SegatexApply *segatex_apply;
     SegatexSetenforce *segatex_apply_for_state;
@@ -157,6 +152,7 @@ private:
     SegatexYumProcess *selinux_yum_process;
     SegatexAudit2allow *selinux_audit2allow;
     BreakTe *breakte_o;
+    BreakIf *breakif_o;
     SegatexCore *segatex_core_o;
     SemoduleCoreProcess *semodule_core_process_o;
     SemanageCoreProcess *semanage_core_process_o;
@@ -174,22 +170,23 @@ private:
     Restorecon *restorecon_o;
     Downloader *downloader_o;
     
-    QPopupMenu *fileMenu;
-    QPopupMenu *editMenu;
-    QPopupMenu *windowsMenu;
-    QPopupMenu *helpMenu;
+    Q3PopupMenu *fileMenu;
+    Q3PopupMenu *editMenu;
+    Q3PopupMenu *windowsMenu;
+    Q3PopupMenu *helpMenu;
     //newly added
-    QPopupMenu *breakteMenu;
-    QPopupMenu *auditMenu;
-    QPopupMenu *policyMenu;
-    QPopupMenu *manageMenu;
-    QPopupMenu *semanageMenu;
-    QPopupMenu *relabelMenu;
-    QPopupMenu *downloaderMenu;
-    QPopupMenu *miscellaneousMenu;
+    Q3PopupMenu *breakteMenu;
+    Q3PopupMenu *breakifMenu;
+    Q3PopupMenu *auditMenu;
+    Q3PopupMenu *policyMenu;
+    Q3PopupMenu *manageMenu;
+    Q3PopupMenu *semanageMenu;
+    Q3PopupMenu *relabelMenu;
+    Q3PopupMenu *downloaderMenu;
+    Q3PopupMenu *miscellaneousMenu;
 
-    QToolBar *fileToolBar;
-    QToolBar *editToolBar;
+    Q3ToolBar *fileToolBar;
+    Q3ToolBar *editToolBar;
     QAction *newAct;
     QAction *openAct;
     QAction *saveAct;
@@ -209,6 +206,7 @@ private:
     QAction *aboutQtAct;
     //newly added
     QAction *breakteAct;
+    QAction *breakifAct;
     QAction *howtouseAct;
     QAction *enforcingAct;
     QAction *check_selinuxAct;
