@@ -22,9 +22,14 @@
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qradiobutton.h>
-#include <qtextedit.h>
-#include <qprocess.h>
+#include <q3textedit.h>
+#include <q3process.h>
 #include <qmessagebox.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+#include <Q3HBoxLayout>
+#include <Q3VBoxLayout>
+#include <QLabel>
 //#include <fstream.h>
 #include <fstream>
 
@@ -37,7 +42,7 @@ using namespace std;
 Seeprocess::Seeprocess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 		setCaption(tr("see process"));
-		textEdit1 = new QTextEdit(this);
+		textEdit1 = new Q3TextEdit(this);
 		textEdit1->setPaletteBackgroundColor(QColor(174,187,255));
 		grepLabel = new QLabel(tr("grep:"), this );
 		grepEditLineEdit = new QLineEdit(this );
@@ -54,12 +59,12 @@ Seeprocess::Seeprocess(QWidget *parent, const char *name): QDialog(parent, name)
 		connect(seeprocessButton, SIGNAL(clicked()), this, SLOT(seeprocess_clicked()));
 		connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 
-		firstLayout = new QVBoxLayout;
-		leftLayout = new QHBoxLayout;
+		firstLayout = new Q3VBoxLayout;
+		leftLayout = new Q3HBoxLayout;
 		leftLayout->addWidget(grepLabel);
 		leftLayout->addWidget(grepEditLineEdit);
 
-		rightLayout = new QVBoxLayout;
+		rightLayout = new Q3VBoxLayout;
 		rightLayout->addWidget(grepButton);
 		rightLayout->addStretch(1);
 		rightLayout->addWidget(seeprocessButton);
@@ -68,7 +73,7 @@ Seeprocess::Seeprocess(QWidget *parent, const char *name): QDialog(parent, name)
 		firstLayout->addLayout(leftLayout);
 		firstLayout->addWidget(textEdit1);
 
-		mainLayout = new QHBoxLayout(this);
+		mainLayout = new Q3HBoxLayout(this);
 		mainLayout->setMargin(11);
 		mainLayout->setSpacing(6);
 		mainLayout->addLayout(firstLayout);
@@ -145,7 +150,7 @@ void Seeprocess::seeprocess_grep_process(QString grep_str)
 void Seeprocess::seeprocess_base_process()
 {
 	this->setEnabled(false);
-	process = new QProcess(this);
+	process = new Q3Process(this);
 	process->addArgument("ps");
 	process->addArgument("-efZ");
 
@@ -181,8 +186,8 @@ void Seeprocess::readFromOutputFile()
 			name = *it_d;
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
+			if ( file.open( QIODevice::ReadOnly ) ) {
+				Q3TextStream stream( &file );
 				////////////////////////////////////////////
 				while ( !stream.atEnd() ) {
 					line_analized = stream.readLine(); // line of text excluding '\n'
@@ -221,8 +226,8 @@ void Seeprocess::readFromOutputFile_grep(QString grep_str)
 			QFile file( file_interface_name );
 			//QRegExp rx_nologin("nologin");
 			QRegExp rx_grep(grep_str);
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
+			if ( file.open( QIODevice::ReadOnly ) ) {
+				Q3TextStream stream( &file );
 				////////////////////////////////////////////
 				int i;
 				while ( !stream.atEnd() ) {
