@@ -20,7 +20,11 @@
 
 #include <qlayout.h>
 #include <qpushbutton.h>
-#include <qprocess.h>
+#include <q3process.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+#include <Q3HBoxLayout>
+#include <Q3VBoxLayout>
 
 #include "segatex_audit2allow_process.h"
 
@@ -31,7 +35,7 @@ using namespace std;
 SegatexAudit2allowProcess::SegatexAudit2allowProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	//setCaption(tr("Audit2allow Process"));
-	textEdit1 = new QTextEdit(this);
+	textEdit1 = new Q3TextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(174,187,255));
 	closeButton = new QPushButton(tr("close"), this);
 	closeButton->setDefault(true);
@@ -40,14 +44,14 @@ SegatexAudit2allowProcess::SegatexAudit2allowProcess(QWidget *parent, const char
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close_button_clicked()));
 	//connect to checkboxes
 
-	QVBoxLayout *headLayout = new QVBoxLayout;
+	Q3VBoxLayout *headLayout = new Q3VBoxLayout;
 	headLayout->addWidget(textEdit1);
 
-	QHBoxLayout *footLayout = new QHBoxLayout;
+	Q3HBoxLayout *footLayout = new Q3HBoxLayout;
 	footLayout->addStretch(1);
 	footLayout->addWidget(closeButton);
 
-	QVBoxLayout *mainLayout = new QVBoxLayout(this);
+	Q3VBoxLayout *mainLayout = new Q3VBoxLayout(this);
 	mainLayout->setMargin(11);
 	mainLayout->setSpacing(6);
 	mainLayout->addLayout(headLayout);
@@ -116,7 +120,7 @@ void SegatexAudit2allowProcess::audit2allow_base_process(int log_file, QString o
 	//devide by 1000  eq 0 and % eq   0 option -no_option
 
 	this->setEnabled(false);
-	process = new QProcess(this);
+	process = new Q3Process(this);
 	process->addArgument("audit2allow");
 
 	if((x == 1)&&(y == 111)){
@@ -246,8 +250,8 @@ void SegatexAudit2allowProcess::readFromOutputFile()
 			name = *it_d;
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
+			if ( file.open( QIODevice::ReadOnly ) ) {
+				Q3TextStream stream( &file );
 				////////////////////////////////////////////
 				while ( !stream.atEnd() ) {
 					line_analized = stream.readLine(); // line of text excluding '\n'
@@ -266,7 +270,7 @@ void SegatexAudit2allowProcess::rm_outputfile_str_common()
 {
 	outputfile_str_common_real = "/root/segatex/" + outputfile_str_common;
 	this->setEnabled(false);
-	process = new QProcess(this);
+	process = new Q3Process(this);
 	process->addArgument("rm");
 	process->addArgument(outputfile_str_common_real);
 }
