@@ -23,7 +23,11 @@
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qradiobutton.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+#include <Q3HBoxLayout>
+#include <Q3VBoxLayout>
 
 #include "segatex_core_process.h"
 
@@ -34,7 +38,7 @@
 SegatexCoreProcess::SegatexCoreProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Denied audit.log"));
-	textEdit1 = new QTextEdit(this);
+	textEdit1 = new Q3TextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(255,187,174));
 	closeButton = new QPushButton(tr("close"), this);
 	closeButton->setDefault(true);
@@ -42,14 +46,14 @@ SegatexCoreProcess::SegatexCoreProcess(QWidget *parent, const char *name): QDial
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close_button_clicked()));
 
-	QVBoxLayout *headLayout = new QVBoxLayout;
+	Q3VBoxLayout *headLayout = new Q3VBoxLayout;
 	headLayout->addWidget(textEdit1);
 
-	QHBoxLayout *footLayout = new QHBoxLayout;
+	Q3HBoxLayout *footLayout = new Q3HBoxLayout;
 	footLayout->addStretch(1);
 	footLayout->addWidget(closeButton);
 
-	QVBoxLayout *mainLayout = new QVBoxLayout(this);
+	Q3VBoxLayout *mainLayout = new Q3VBoxLayout(this);
 	mainLayout->setMargin(11);
 	mainLayout->setSpacing(6);
 	mainLayout->addLayout(headLayout);
@@ -88,13 +92,13 @@ void SegatexCoreProcess::segatex_core_pre()
 		file_w.remove();
 	}
 	
-	if ( file_w.open( IO_WriteOnly | IO_Append ) ) {
+	if ( file_w.open( QIODevice::WriteOnly | QIODevice::Append ) ) {
 		while(it_d != files.end()){
 			name = *it_d;
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
+			if ( file.open( QIODevice::ReadOnly ) ) {
+				Q3TextStream stream( &file );
 				//QTextStream stream_echo( &file );
 				var1="$1";
 				var2="$2";
@@ -124,7 +128,7 @@ void SegatexCoreProcess::segatex_core_pre()
 						lines += line_analized;
 				        }
 				}
-				QTextStream stream_w( &file_w );
+				Q3TextStream stream_w( &file_w );
 				for ( it = lines.begin(); it != lines.end(); ++it ){
 					stream_w << *it << "\n";
 				}
@@ -138,8 +142,8 @@ void SegatexCoreProcess::segatex_core_pre()
 	}
 	//echo
 	file_w.close();
-	if ( file_w.open( IO_ReadOnly ) ) {
-		QTextStream stream( &file_w );
+	if ( file_w.open( QIODevice::ReadOnly ) ) {
+		Q3TextStream stream( &file_w );
 		textEdit1->setText( stream.read() );
 	}
 }//end-segatex_core_pre()
