@@ -21,9 +21,14 @@
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <qradiobutton.h>
-#include <qbuttongroup.h>
+#include <q3buttongroup.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+#include <Q3HBoxLayout>
+#include <Q3VBoxLayout>
+#include <QLabel>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -40,7 +45,7 @@ using namespace std;
 SemanageCoreBooleanProcess::SemanageCoreBooleanProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Setsebool Process"));
-	textEdit1 = new QTextEdit(this);
+	textEdit1 = new Q3TextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
 
 	semanageEditLabel = new QLabel(tr("Boolean:"), this );
@@ -48,7 +53,7 @@ SemanageCoreBooleanProcess::SemanageCoreBooleanProcess(QWidget *parent, const ch
 	semanageEditLineEdit->setText("");
 	semanageEditLineEdit->setPaletteBackgroundColor(QColor(200,254,100));
 	
-	timeButtonGroup = new QButtonGroup(this);
+	timeButtonGroup = new Q3ButtonGroup(this);
 	timeButtonGroup->resize( 200, 200 );
 	temporaryRadioButton = new QRadioButton(tr("temporary"), timeButtonGroup);
 	permanentRadioButton = new QRadioButton(tr("permanent"), timeButtonGroup);
@@ -72,16 +77,16 @@ SemanageCoreBooleanProcess::SemanageCoreBooleanProcess(QWidget *parent, const ch
 	//set textEdit smanage such and such -l
 	semanage_core_base_boolean_process();
 
-	mainLayout = new QVBoxLayout(this);
+	mainLayout = new Q3VBoxLayout(this);
 	mainLayout->setMargin(11);
 
-	upperLayout = new QVBoxLayout;
+	upperLayout = new Q3VBoxLayout;
 	upperLayout->addWidget(textEdit1);
 
-	middleLayout = new QVBoxLayout;
-	leftLayout = new QHBoxLayout;
-	rightLayout = new QHBoxLayout;
-	thirdLayout = new QHBoxLayout;
+	middleLayout = new Q3VBoxLayout;
+	leftLayout = new Q3HBoxLayout;
+	rightLayout = new Q3HBoxLayout;
+	thirdLayout = new Q3HBoxLayout;
 	
 	leftLayout->addWidget(semanageEditLabel);
 	leftLayout->addWidget(semanageEditLineEdit);
@@ -94,7 +99,7 @@ SemanageCoreBooleanProcess::SemanageCoreBooleanProcess(QWidget *parent, const ch
 	middleLayout->addLayout(rightLayout);
 	middleLayout->addLayout(thirdLayout);
 
-	footLayout = new QHBoxLayout;
+	footLayout = new Q3HBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 
@@ -201,8 +206,8 @@ void SemanageCoreBooleanProcess::readFromOutputFile()
 			name = *it_d;
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
+			if ( file.open( QIODevice::ReadOnly ) ) {
+				Q3TextStream stream( &file );
 				////////////////////////////////////////////
 				//int i,j,k,l,m,n;	
 				if(order_x == 1)
