@@ -26,9 +26,12 @@
 #include <qdir.h> 
 #include <qregexp.h> 
 #include <qlabel.h> 
-#include <qtextedit.h>
-#include <qbuttongroup.h>
+#include <q3textedit.h>
+#include <q3buttongroup.h>
 #include <qradiobutton.h>
+//Added by qt3to4:
+#include <Q3HBoxLayout>
+#include <Q3VBoxLayout>
 
 
 class QLayout;
@@ -56,12 +59,12 @@ private slots:
 	void readFromOutputFile();
 public:
 private:
-	QButtonGroup *filetypeButtonGroup;
+	Q3ButtonGroup *filetypeButtonGroup;
 	QPushButton *addButton;
 	QPushButton *deleteButton;
 	QPushButton *modifyButton;
 	QPushButton *closeButton;
-	QTextEdit *textEdit1;
+	Q3TextEdit *textEdit1;
 	QRadioButton *allfilesRadioButton;
 	QRadioButton *regularfileRadioButton;
 	QRadioButton *directoryRadioButton;
@@ -71,15 +74,15 @@ private:
 	QRadioButton *symboliclinkRadioButton;
 	QRadioButton *namedpipeRadioButton;
 
-	QVBoxLayout *mainLayout;
-	QVBoxLayout *upperLayout;
-	QVBoxLayout *underLayout;
-	QHBoxLayout *leftLayout;
-	QHBoxLayout *rightLayout;
-	QHBoxLayout *thirdLayout;
-	QHBoxLayout *fourthLayout;
-	QVBoxLayout *middleLayout;
-	QHBoxLayout *footLayout;
+	Q3VBoxLayout *mainLayout;
+	Q3VBoxLayout *upperLayout;
+	Q3VBoxLayout *underLayout;
+	Q3HBoxLayout *leftLayout;
+	Q3HBoxLayout *rightLayout;
+	Q3HBoxLayout *thirdLayout;
+	Q3HBoxLayout *fourthLayout;
+	Q3VBoxLayout *middleLayout;
+	Q3HBoxLayout *footLayout;
 
         QDir dir;
         QString path;
