@@ -20,11 +20,16 @@
 
 #include <qlayout.h>
 #include <qpushbutton.h>
-#include <qprocess.h>
+#include <q3process.h>
 #include <qradiobutton.h>
-#include <qbuttongroup.h>
+#include <q3buttongroup.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+#include <Q3HBoxLayout>
+#include <QLabel>
+#include <Q3VBoxLayout>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -41,7 +46,7 @@ using namespace std;
 SemanageCoreLoginProcess::SemanageCoreLoginProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Semanage Login Process"));
-	textEdit1 = new QTextEdit(this);
+	textEdit1 = new Q3TextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
 
 	semanageEditLabel = new QLabel(tr("Add Unix user:"), this );
@@ -92,16 +97,16 @@ SemanageCoreLoginProcess::SemanageCoreLoginProcess(QWidget *parent, const char *
 	//set textEdit smanage such and such -l
 	semanage_core_base_login_process();
 
-	mainLayout = new QVBoxLayout(this);
+	mainLayout = new Q3VBoxLayout(this);
 	mainLayout->setMargin(11);
 
-	upperLayout = new QVBoxLayout;
+	upperLayout = new Q3VBoxLayout;
 	upperLayout->addWidget(textEdit1);
 
-	middleLayout = new QVBoxLayout;
-	leftLayout = new QHBoxLayout;
-	rightLayout = new QHBoxLayout;
-	thirdLayout = new QHBoxLayout;
+	middleLayout = new Q3VBoxLayout;
+	leftLayout = new Q3HBoxLayout;
+	rightLayout = new Q3HBoxLayout;
+	thirdLayout = new Q3HBoxLayout;
 	
 	leftLayout->addWidget(semanageEditLabel);
 	leftLayout->addWidget(semanageEditLineEdit);
@@ -125,7 +130,7 @@ SemanageCoreLoginProcess::SemanageCoreLoginProcess(QWidget *parent, const char *
 	middleLayout->addLayout(rightLayout);
 	middleLayout->addLayout(thirdLayout);
 
-	footLayout = new QHBoxLayout;
+	footLayout = new Q3HBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 
@@ -360,8 +365,8 @@ void SemanageCoreLoginProcess::readFromOutputFile()
 			QRegExp rx_news("news");
 			QRegExp rx_false("false");
 			QRegExp rx_sync("sync");
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
+			if ( file.open( QIODevice::ReadOnly ) ) {
+				Q3TextStream stream( &file );
 				////////////////////////////////////////////
 				int i,j,k,l,m,n;	
 				if(order_x == 1)
