@@ -20,12 +20,16 @@
 
 #include <qlayout.h>
 #include <qpushbutton.h>
-#include <qprocess.h>
+#include <q3process.h>
 #include <qradiobutton.h>
-#include <qbuttongroup.h>
+#include <q3buttongroup.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qprocess.h>
+#include <q3textedit.h>
+#include <q3process.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+#include <Q3HBoxLayout>
+#include <Q3VBoxLayout>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -43,7 +47,7 @@ using namespace std;
 SemanageCoreProcess::SemanageCoreProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Semanage Process"));
-	textEdit1 = new QTextEdit(this);
+	textEdit1 = new Q3TextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(200,254,100));
 	closeButton = new QPushButton(tr("close"), this);
 	//closing process button
@@ -53,13 +57,13 @@ SemanageCoreProcess::SemanageCoreProcess(QWidget *parent, const char *name): QDi
 	//set textEdit smanage such and such -l
 	semanage_core_base_process();
 
-	mainLayout = new QVBoxLayout(this);
+	mainLayout = new Q3VBoxLayout(this);
 	mainLayout->setMargin(11);
 
-	upperLayout = new QVBoxLayout;
+	upperLayout = new Q3VBoxLayout;
 	upperLayout->addWidget(textEdit1);
 
-	footLayout = new QHBoxLayout;
+	footLayout = new Q3HBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 
@@ -461,8 +465,8 @@ void SemanageCoreProcess::readFromOutputFile()
 			name = *it_d;
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
+			if ( file.open( QIODevice::ReadOnly ) ) {
+				Q3TextStream stream( &file );
 				////////////////////////////////////////////
 				if(order_x == 1)
 					textEdit1->append("#########login list#########");
